## About this package

This package is available on https://pypi.org/project/meuip/ , know in your command line your ip, isp, country, asn, region, latitude, longitude, countryCode

Code on github
https://github.com/rafaelscone/meuip

## Apis this script use 
- http://ip-api.com/json
- https://api.myip.com
- https://api.my-ip.io/ip
- https://api.ipify.org?format=json
- https://ipapi.co/json/

## How to install 

```bash
pip3 install meuip
```

## How to use

```bash
meuip --help
```

You can choose more than one option
- ip  = to see the ip address
- isp  = to see the isp provider
- country  = to see your contry
- countryCode  = to see your Contry Code
- city  = to see your city
- region  = to see your region
- latitude  = to see your latitude
- longitude  = to see your longitude


```bash
meuip isp
```

### Feel free to send me news, bugs and suggestions to this package
Rafael Schneider - rafaelscone


